@@ -11,7 +11,7 @@ use URPM::Resolve;
 use URPM::Signature;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = 'v5.24.1';
+our $VERSION = '5.17';
 
 URPM->bootstrap($VERSION);
 
@@ -874,7 +874,6 @@ Recognized options are:
     callback_open   => sub { ... }
     callback_trans  => sub { ... }
     callback_uninst => sub { ... }
-    callback_verify => sub { ... }
     delta => used for progress callbacks (trans, uninst, inst)
     excludedocs => 0 / 1
     force => 0 / 1
@@ -887,13 +886,13 @@ Recognized options are:
 
 They roughly correspond to command-line options to rpm(1).
 
-'callback_open' signature is (C<$data>, C<$cb_type>, C<$pkg_id>). It _must_ return a file handler for the asked package.
+'callback_open' signature is (C<$data>, C<$cb_type>, C<$pkg_id>, C<pkg_name>). It _must_ return a file handler for the asked package.
 
-'callback_close' signature is (C<$data>, C<$cb_type>, C<$pkg_id>). It is called just before URPM close the fd for the installed package.
+'callback_close' signature is (C<$data>, C<$cb_type>, C<$pkg_id>, C<pkg_name>). It is called just before URPM close the fd for the installed package.
 
 C<$cb_type> is one of 'open' or 'close'.
 
-Other Callbacks signature is callback(C<$data>, C<$cb_type>, C<$pkg_id>, C<$subtype>, C<$amout>, C<$total>)
+Other Callbacks signature is callback(C<$data>, C<$cb_type>, C<$pkg_id>, C<$subtype>, C<$amout>, C<$total>, C<pkg_name>)
 
 C<$cb_type> is one of 'elem', 'error', 'inst', 'trans' or 'uninst'. C<$subtype> can be 'start', 'progress' or 'stop'.
 For 'error', it can be 'cpio', 'script' or 'unpack'.
@@ -1044,8 +1043,6 @@ B<transaction_state>: $state object
 
 The L<URPM::Resolve> implements the resolving bits.
 
-The L<URPM::Signature> implements the pubkey bits.
-
 The L<urpm> package is a higher level module used by the urpmi command line tool,
 the rpmdrake GUI and the drakx installer.
 
